@@ -19,7 +19,7 @@ test_that("createEnrichMap() must return error when gostObject is a number", {
     
     expect_error(createEnrichMap(gostObject=33, query="TEST", 
         source="GO:CC", termIDs=NULL, removeRoot=TRUE,
-        showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        showCategory=30, categoryLabel=1,
         categoryNode=1, line=1), error_message)
 })
 
@@ -32,7 +32,7 @@ test_that("createEnrichMap() must return error when gostObject is a string chara
     
     expect_error(createEnrichMap(gostObject="TEST", query="TEST", 
         source="GO:CC", termIDs=NULL, removeRoot=TRUE, 
-        showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        showCategory=30, categoryLabel=1,
         categoryNode=1, line=1), error_message)
 })
 
@@ -47,7 +47,7 @@ test_that("createEnrichMap() must return error when query is a number", {
     
     expect_error(createEnrichMap(gostObject=gostObject, query=33, 
         source="KEGG", termIDs=NULL, removeRoot=TRUE, 
-        showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        showCategory=30, categoryLabel=1,
         categoryNode=1, line=1), error_message)
 })
 
@@ -62,7 +62,7 @@ test_that("createEnrichMap() must return error when query is a vector of strings
     
     expect_error(createEnrichMap(gostObject=gostObject, query=c("1", "2"), 
         source="KEGG", termIDs=NULL, removeRoot=TRUE, 
-        showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        showCategory=30, categoryLabel=1,
         categoryNode=1, line=1), error_message)
 })
 
@@ -74,7 +74,7 @@ test_that("createEnrichMap() must return error when query is not in gost", {
     
     expect_error(createEnrichMap(gostObject=demoGOST, query="CANADA", 
         source="KEGG", termIDs=NULL, removeRoot=TRUE,
-        showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        showCategory=30, categoryLabel=1,
         categoryNode=1, line=1), error_message)
 })
 
@@ -90,7 +90,7 @@ test_that("createEnrichMap() must return error when source is a number", {
     
     expect_error(createEnrichMap(gostObject=gostObject, query="toto", 
         source=333, termIDs=NULL, removeRoot=TRUE, 
-        showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        showCategory=30, categoryLabel=1,
         categoryNode=1, line=1),  error_message)
 })
 
@@ -102,8 +102,7 @@ test_that("createEnrichMap() must return error when source is a wrong name", {
     
     expect_error(createEnrichMap(gostObject=gostObject, query="toto",  
         source="test", termIDs=NULL, removeRoot=TRUE, title="network", 
-        showCategory=30, groupCategory=FALSE, categoryLabel=1,
-        categoryNode=1, line=1))
+        showCategory=30, categoryLabel=1, categoryNode=1, line=1))
 })
 
 
@@ -116,8 +115,7 @@ test_that("createEnrichMap() must return error when source is GO", {
     expect_error(createEnrichMap(gostObject=gostObject, query="toto", 
         source="GO",
         termIDs=NULL, removeRoot=TRUE, 
-        showCategory=30, groupCategory=FALSE, categoryLabel=1,
-        categoryNode=1, line=1))
+        showCategory=30, categoryLabel=1, categoryNode=1, line=1))
 })
 
 
@@ -131,7 +129,7 @@ test_that("createEnrichMap() must return error when removeRoot remove last enric
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
                     source="WP", removeRoot=TRUE, 
-                    showCategory=30, groupCategory=FALSE, categoryLabel=1,
+                    showCategory=30, categoryLabel=1,
                     categoryNode=1, line=1), error_message)
 })
 
@@ -147,8 +145,7 @@ test_that("createEnrichMap() must return error when removeRoot remove last enric
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
         source="TERM_ID",
         termIDs=c("WP:000000"), removeRoot=TRUE, showCategory=30, 
-        groupCategory=FALSE, categoryLabel=1,
-        categoryNode=1, line=1), error_message)
+        categoryLabel=1, categoryNode=1, line=1), error_message)
 })
 
 
@@ -161,8 +158,7 @@ test_that("createEnrichMap() must return error when showCategory negative value"
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
                     source="WP", removeRoot=TRUE, showCategory=-30, 
-                    groupCategory=FALSE, categoryLabel=1,
-                    categoryNode=1, line=2), error_message)
+                    categoryLabel=1, categoryNode=1, line=2), error_message)
 })
 
 
@@ -175,22 +171,7 @@ test_that("createEnrichMap() must return error when showCategory is boolean", {
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
                     source="WP", removeRoot=TRUE, showCategory=TRUE, 
-                    groupCategory=FALSE, categoryLabel=1,
-                    categoryNode=1, line=1), error_message)
-})
-
-
-test_that("createEnrichMap() must return error when groupCategory is integer", {
-    
-    gostTerm <- demoGOST
-    
-    error_message <- paste0("The \'groupCategory\' parameter must a logical ", 
-                                "(TRUE or FALSE).")
-    
-    expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
-            source="WP", removeRoot=TRUE, showCategory=30, 
-            groupCategory=22, categoryLabel=1,
-            categoryNode=1, line=1), error_message, fixed=TRUE)
+                    categoryLabel=1, categoryNode=1, line=1), error_message)
 })
 
 
@@ -203,8 +184,7 @@ test_that("createEnrichMap() must return error when categoryLabel is string", {
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
             source="WP", removeRoot=TRUE, showCategory=30, 
-            groupCategory=FALSE, categoryLabel="test",
-            categoryNode=1, line=2), error_message, fixed=TRUE)
+            categoryLabel="test",categoryNode=1, line=2), error_message, fixed=TRUE)
 })
 
 
@@ -217,8 +197,8 @@ test_that("createEnrichMap() must return error when cexLabelCategory is negative
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
             source="WP", removeRoot=TRUE, showCategory=30, 
-            groupCategory=FALSE, categoryLabel=-1.1,
-            categoryNode=1, line=2), error_message, fixed=TRUE)
+            categoryLabel=-1.1, categoryNode=1, line=2), error_message, 
+            fixed=TRUE)
 })
 
 
@@ -230,9 +210,8 @@ test_that("createEnrichMap() must return error when categoryNode is negative", {
                                 "must be a positive numeric.")
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
-                    source="WP", removeRoot=TRUE, showCategory=30, 
-                    groupCategory=FALSE, categoryLabel=2,
-                    categoryNode=-1), error_message, fixed=TRUE)
+        source="WP", removeRoot=TRUE, showCategory=30, 
+        categoryLabel=2, categoryNode=-1), error_message, fixed=TRUE)
 })
 
 
@@ -245,8 +224,8 @@ test_that("createEnrichMap() must return error when categoryNode is string", {
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
             source="WP", removeRoot=TRUE, showCategory=30, 
-            groupCategory=FALSE, categoryLabel=2,
-            categoryNode="te", line=1), error_message, fixed=TRUE)
+            categoryLabel=2, categoryNode="te", line=1), error_message, 
+            fixed=TRUE)
 })
 
 test_that("createEnrichMap() must return error when line is a string", {
@@ -257,7 +236,7 @@ test_that("createEnrichMap() must return error when line is a string", {
                                 "positive numeric.")
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
-        source="WP", removeRoot=TRUE,  showCategory=30, groupCategory=FALSE, 
+        source="WP", removeRoot=TRUE,  showCategory=30, 
         categoryLabel=1, categoryNode=1, line="HI"), 
         error_message, fixed=TRUE)
 })
@@ -270,7 +249,7 @@ test_that("createEnrichMap() must return error when line is a negative number",
                                 "positive numeric.")
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
-        source="WP", removeRoot=TRUE,  showCategory=30, groupCategory=FALSE, 
+        source="WP", removeRoot=TRUE,  showCategory=30, 
         categoryLabel=1, categoryNode=1, line=-0.3), 
         error_message, fixed=TRUE)
 })
@@ -284,7 +263,7 @@ test_that("createEnrichMap() must return error when not term for selected source
                                 "source \'WP'.")
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
-        source="WP", removeRoot=TRUE,  showCategory=30, groupCategory=FALSE, 
+        source="WP", removeRoot=TRUE,  showCategory=30, 
         categoryLabel=1, categoryNode=1, line=1), error_message, 
                  fixed=TRUE)
 })
@@ -298,8 +277,7 @@ test_that("createEnrichMap() must return error when not term id and TERM_ID sele
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
         source="TERM_ID", removeRoot=TRUE,  showCategory=30, 
-        groupCategory=FALSE, categoryLabel=1, categoryNode=1, line=1), 
-        error_message, fixed=TRUE)
+        categoryLabel=1, categoryNode=1, line=1), error_message, fixed=TRUE)
 })
 
 test_that("createEnrichMap() must return error when not all term ids are present", {
@@ -311,9 +289,8 @@ test_that("createEnrichMap() must return error when not all term ids are present
     
     expect_error(createEnrichMap(gostObject=gostTerm, query="query_1", 
         source="TERM_ID", termIDs = c("GO:0051173", "GO:0065004", "GO:1905898"), 
-        removeRoot=TRUE,  showCategory=30, 
-        groupCategory=FALSE, categoryLabel=1, categoryNode=1, line=1), 
-        error_message, fixed=TRUE)
+        removeRoot=TRUE,  showCategory=30, categoryLabel=1, 
+        categoryNode=1, line=1), error_message, fixed=TRUE)
 })
 
 
@@ -328,7 +305,7 @@ test_that("createEnrichMapMultiBasic() must return error when gostObjectList is
     
     expect_error(createEnrichMapMultiBasic(gostObjectList=33, 
         queryList=c("TEST", "Test2"),  source="GO:CC", termIDs=NULL, 
-        removeRoot=TRUE, showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        removeRoot=TRUE, showCategory=30, categoryLabel=1,
         categoryNode=1, line=1), error_message)
 })
 
@@ -341,8 +318,7 @@ test_that("createEnrichMapMultiBasic() must return error when gostObjectList has
     
     expect_error(createEnrichMapMultiBasic(gostObjectList=list(gostTerm), 
         queryList=list("TEST"), source="GO:CC", termIDs=NULL, removeRoot=TRUE, 
-        showCategory=30, groupCategory=FALSE, categoryLabel=1,
-        categoryNode=1), error_message)
+        showCategory=30, categoryLabel=1, categoryNode=1), error_message)
 })
 
 test_that("createEnrichMapMultiBasic() must return error when queryList is a number", {
@@ -355,8 +331,7 @@ test_that("createEnrichMapMultiBasic() must return error when queryList is a num
     
     expect_error(createEnrichMapMultiBasic(gostObjectList=list(gostTerm, gostTerm), 
         queryList=33, source="GO:CC", termIDs=NULL, removeRoot=TRUE, 
-        showCategory=30, groupCategory=FALSE, categoryLabel=1,
-        categoryNode=1), error_message)
+        showCategory=30, categoryLabel=1, categoryNode=1), error_message)
 })
 
 test_that("createEnrichMapMultiBasic() must return error when queryList is longer than gostObjectList", {
@@ -369,7 +344,7 @@ test_that("createEnrichMapMultiBasic() must return error when queryList is longe
     
     expect_error(createEnrichMapMultiBasic(gostObjectList=list(gostTerm, gostTerm), 
     queryList=list("TEST", "TEST2", "TEST3"), source="GO:CC", termIDs=NULL, 
-    removeRoot=TRUE, showCategory=30, groupCategory=FALSE, categoryLabel=1,
+    removeRoot=TRUE, showCategory=30, categoryLabel=1,
     categoryNode=1), error_message)
 })
 
@@ -383,7 +358,7 @@ test_that("createEnrichMapMultiBasic() must return error when one query in query
     
     expect_error(createEnrichMapMultiBasic(gostObjectList=list(gostTerm, gostTerm), 
         queryList=list("query_1", "TEST"), source="GO:CC", termIDs=NULL, 
-        removeRoot=TRUE, showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        removeRoot=TRUE, showCategory=30, categoryLabel=1,
         categoryNode=1), error_message, fixed=TRUE)
 })
 
@@ -398,7 +373,7 @@ test_that("createEnrichMapMultiBasic() must return error when one object in gost
     
     expect_error(createEnrichMapMultiBasic(gostObjectList=list(gostTerm, 33), 
         queryList=list("query_1", "query_1"), source="GO:CC", termIDs=NULL, 
-        removeRoot=TRUE, showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        removeRoot=TRUE, showCategory=30, categoryLabel=1,
         categoryNode=1), error_message, fixed=TRUE)
 })
 
@@ -412,7 +387,7 @@ test_that("createEnrichMapMultiBasic() must return error when no enriched term f
     
     expect_error(createEnrichMapMultiBasic(gostObjectList=list(gostTerm, gostTerm), 
         queryList=list("query_1", "query_1"), source="WP", termIDs=NULL, 
-        removeRoot=TRUE, showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        removeRoot=TRUE, showCategory=30, categoryLabel=1,
         categoryNode=1), error_message, fixed=TRUE)
 })
 
@@ -425,7 +400,7 @@ test_that("createEnrichMapMultiBasic() must return error when number in queryLis
     
     expect_error(createEnrichMapMultiBasic(gostObjectList=list(gostTerm, gostTerm), 
         queryList=list("query_1", 33), source="WP", termIDs=NULL, 
-        removeRoot=TRUE, showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        removeRoot=TRUE, showCategory=30, categoryLabel=1,
         categoryNode=1), error_message, fixed=TRUE)
 })
 
@@ -438,7 +413,7 @@ test_that("createEnrichMapMultiBasic() must return error when number in queryLis
     
     expect_error(createEnrichMapMultiBasic(gostObjectList=list(gostTerm, gostTerm), 
         queryList=list("query_1", "query_1"), source="TERM_ID", termIDs=NULL, 
-        removeRoot=TRUE, showCategory=30, groupCategory=FALSE, categoryLabel=1,
+        removeRoot=TRUE, showCategory=30, categoryLabel=1,
         categoryNode=1), error_message, fixed=TRUE)
 })
 
@@ -724,7 +699,7 @@ test_that("createEnrichMapMultiComplex() must return error when gostObjectList i
         termIDs=c("", "", ""), stringsAsFactors=FALSE)
     
     expect_error(createEnrichMapMultiComplex(gostObjectList=33, 
-        queryInfo=queryDF,  showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDF,  showCategory=30, 
         categoryLabel=1, categoryNode=1, line=1), error_message)
 })
 
@@ -740,8 +715,8 @@ test_that("createEnrichMapMultiComplex() must return error when gostObjectList h
         "of enrichment objects. At least 2 enrichment objects are required.")
     
     expect_error(createEnrichMapMultiComplex(gostObjectList=list(gostTerm), 
-        queryInfo=queryDF, showCategory=30, groupCategory=FALSE, 
-        categoryLabel=1, categoryNode=1), error_message)
+        queryInfo=queryDF, showCategory=30, categoryLabel=1, categoryNode=1), 
+        error_message)
 })
 
 test_that("createEnrichMapMultiComplex() must return error when gostObjectList is a list of numbers", {
@@ -752,8 +727,7 @@ test_that("createEnrichMapMultiComplex() must return error when gostObjectList i
         " output.")
     
     expect_error(createEnrichMapMultiComplex(
-        gostObjectList=list(3, 4), 
-        queryInfo=33, showCategory=30, groupCategory=FALSE, 
+        gostObjectList=list(3, 4), queryInfo=33, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message)
 })
 
@@ -765,8 +739,7 @@ test_that("createEnrichMapMultiComplex() must return error when queryInfo is a n
             "those columns: queryName, source, removeRoot and termIDs.")
     
     expect_error(createEnrichMapMultiComplex(
-        gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=33, showCategory=30, groupCategory=FALSE, 
+        gostObjectList=list(gostTerm, gostTerm), queryInfo=33, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message)
 })
 
@@ -783,7 +756,7 @@ test_that("createEnrichMapMultiComplex() must return error when queryInfo shorte
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message)
 })
 
@@ -802,7 +775,7 @@ test_that("createEnrichMapMultiComplex() must return error when source in queryI
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message)
 })
 
@@ -819,7 +792,7 @@ test_that("createEnrichMapMultiComplex() must return error when source in queryI
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30,  
         categoryLabel=1, categoryNode=1), error_message)
 })
 
@@ -836,7 +809,7 @@ test_that("createEnrichMapMultiComplex() must return error when queryName in que
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message)
 })
 
@@ -853,7 +826,7 @@ test_that("createEnrichMapMultiComplex() must return error when termIDs in query
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30,  
         categoryLabel=1, categoryNode=1), error_message)
 })
 
@@ -870,7 +843,7 @@ test_that("createEnrichMapMultiComplex() must return error when removeRoot in qu
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message, fixed=TRUE)
 })
 
@@ -888,7 +861,7 @@ test_that("createEnrichMapMultiComplex() must return error when query name in qu
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message, fixed=TRUE)
 })
 
@@ -905,7 +878,7 @@ test_that("createEnrichMapMultiComplex() must return error when TERM_ID in query
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message, fixed=TRUE)
 })
 
@@ -922,7 +895,7 @@ test_that("createEnrichMapMultiComplex() must return error when termIDs column i
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message, 
         fixed=TRUE)
 })
@@ -940,7 +913,7 @@ test_that("createEnrichMapMultiComplex() must return error when removeRoot colum
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message, 
         fixed=TRUE)
 })
@@ -959,7 +932,7 @@ test_that("createEnrichMapMultiComplex() must return error when groupName column
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30, 
         categoryLabel=1, categoryNode=1), error_message, 
         fixed=TRUE)
 })
@@ -978,7 +951,7 @@ test_that("createEnrichMapMultiComplex() must return error when groupName column
     
     expect_error(createEnrichMapMultiComplex(
         gostObjectList=list(gostTerm, gostTerm), 
-        queryInfo=queryDataFrame, showCategory=30, groupCategory=FALSE, 
+        queryInfo=queryDataFrame, showCategory=30,  
         categoryLabel=1, categoryNode=1), error_message, 
         fixed=TRUE)
 })
